[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [kde4support] cmake: Rename as FindDocBookXML4, it will be used only for DocBook 4.x
From:       Luigi Toscano <luigi.toscano () tiscali ! it>
Date:       2014-03-04 22:33:47
Message-ID: E1WKxuF-0001PN-P6 () scm ! kde ! org
[Download RAW message or body]

Git commit 33f4a855a20df233c5e8c442cbef3cf2b969895c by Luigi Toscano.
Committed on 22/02/2014 at 01:23.
Pushed by ltoscano into branch 'master'.

Rename as FindDocBookXML4, it will be used only for DocBook 4.x

The rename reflects the fact that it is used for DocBookXML4 only;
a future DocBookXML5 could be added if needed.

Use the new module name in CMake files.


Commit d87c5fe9f84e927b2a837b9943231d8b1acd9716 in kdoctools

R  +14   -12   cmake/FindDocBookXML4.cmake [from: cmake/FindDocBookXML.cmak=
e - 071% similarity]

http://commits.kde.org/kde4support/33f4a855a20df233c5e8c442cbef3cf2b969895c

diff --git a/cmake/FindDocBookXML.cmake b/cmake/FindDocBookXML4.cmake
similarity index 71%
rename from cmake/FindDocBookXML.cmake
rename to cmake/FindDocBookXML4.cmake
index b2fd357..3643761 100644
--- a/cmake/FindDocBookXML.cmake
+++ b/cmake/FindDocBookXML4.cmake
@@ -1,11 +1,13 @@
-# Try to find DocBook XML DTDs
+# Try to find DocBook XML 4.x DTD.
+# By default it will find version 4.2. A different version can be specified
+# as parameter for find_package().
 # Once done, it will define:
 #
 #  DocBookXML_FOUND - system has the requested DocBook XML DTDs
 #  DocBookXML_DTD_VERSION - the version of requested DocBook XML
 #     DTD
 #  DocBookXML_DTD_DIR - the directory containing the definition of
 #     the DocBook XML
 =

 # Copyright (c) 2010, 2014 Luigi Toscano, <luigi.toscano@tiscali.it>
 #
@@ -17,7 +19,7 @@ if (NOT DocBookXML_FIND_VERSION)
      set(DocBookXML_FIND_VERSION "4.2")
 endif ()
 =

-set (DocBookXML_DTD_VERSION ${DocBookXML_FIND_VERSION}
+set (DocBookXML4_DTD_VERSION ${DocBookXML_FIND_VERSION}
      CACHE INTERNAL "Required version of DocBook4 XML DTDs")
 =

 function (locate_version version found_dir)
@@ -56,12 +58,12 @@ function (locate_version version found_dir)
 endfunction()
 =

 =

-locate_version (${DocBookXML_DTD_VERSION} DocBookXML_DTD_DIR)
+locate_version (${DocBookXML4_DTD_VERSION} DocBookXML4_DTD_DIR)
 =

 include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args (DocBookXML
-    REQUIRED_VARS DocBookXML_DTD_DIR DocBookXML_DTD_VERSION
-    FOUND_VAR DocBookXML_FOUND)
+find_package_handle_standard_args (DocBookXML4
+    REQUIRED_VARS DocBookXML4_DTD_DIR DocBookXML4_DTD_VERSION
+    FOUND_VAR DocBookXML4_FOUND)
 =

 #maintain backwards compatibility
 # legacy version
@@ -71,4 +73,4 @@ if (DOCBOOKXML_CURRENTDTD_DIR)
     set(DOCBOOKXML_CURRENTDTD_VERSION "4.2")
 endif ()
 =

-mark_as_advanced (DocBookXML_DTD_DIR DocBookXML_DTD_VERSION)
+mark_as_advanced (DocBookXML4_DTD_DIR DocBookXML4_DTD_VERSION)
@@ -1,11 +1,13 @@
 # Once done, it will define:
 #
-#  DocBookXML_FOUND - system has the requested DocBook XML DTDs
-#  DocBookXML_DTD_VERSION - the version of requested DocBook XML
-#     DTD
-#  DocBookXML_DTD_DIR - the directory containing the definition of
-#     the DocBook XML
+#  DocBookXML4_FOUND - system has the requested DocBook4 XML DTDs
+#  DocBookXML4_DTD_VERSION - the version of requested DocBook4
+#     XML DTD
+#  DocBookXML4_DTD_DIR - the directory containing the definition of
+#     the DocBook4 XML
 =


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic